""" Constants """

ID_REPLY = "IDTCMV001"
ID_WAIT_HISTORY = "IDTWAITPCR"
CONTINUE_REQUEST = [0xa5]
START_REQUEST = [0x5a]
PACKET_ID_HISTORY = 0xa9
PACKET_ID_HISTORY_DATA = 0x59
PACKET_ID_REALTIME = 0x51

RECORD_LENGTH = "RL"
CURRENT = "Current"
BAUD_RATE = "BAUD"
BYTE_ORDER = "BO"
LSB = "lsb"
MSB = "msb"
MULTIPLIER = "MP"
TIMEOUT = "TO"